GEOUNED Documentation
=====================

**Version**: |version|

GEOUNED converts CAD to Constructive Solid Geometry (CSG) formats for use in
Monte Carlo transport codes.
Supported codes include OpenMC, PHITS, Serpent and MCNP.

.. toctree::
   :maxdepth: 2

   quick_install_guide
   users_guide/index
   python_api
   developers_guide
